ProSHADE: src/proshade/ProSHADE_misc.hpp File Reference

| ProSHADE 0.7.5.1 (JAN 2021) Protein Shape Detection

Namespaces | Functions
ProSHADE_misc.hpp File Reference

This header file declares all miscellaneous functions. More...

`#include "ProSHADE_messages.hpp"`

Go to the source code of this file.

## Namespaces
| ProSHADE_internal_misc
| This namespace contains all the miscellaneous functions used throughout the code but unrelated to it.

## Functions
void | ProSHADE_internal_misc::addToStringVector (std::vector< std::string > *vecToAddTo, std::string elementToAdd)
| Adds the element to the vector. More...
void | ProSHADE_internal_misc::addToSingleVector (std::vector< proshade_single > *vecToAddTo, proshade_single elementToAdd)
| Adds the element to the vector. More...
void | ProSHADE_internal_misc::addToDoubleVector (std::vector< proshade_double > *vecToAddTo, proshade_double elementToAdd)
| Adds the element to the vector. More...
void | ProSHADE_internal_misc::addToUnsignVector (std::vector< proshade_unsign > *vecToAddTo, proshade_unsign elementToAdd)
| Adds the element to the vector. More...
void | ProSHADE_internal_misc::addToSignedVector (std::vector< proshade_signed > *vecToAddTo, proshade_signed elementToAdd)
| Adds the element to the vector. More...
void | ProSHADE_internal_misc::addToDblPtrVector (std::vector< proshade_double * > *vecToAddTo, proshade_double *elementToAdd)
| Adds the element to the vector. More...
void | ProSHADE_internal_misc::addToSigPtrVector (std::vector< proshade_signed * > *vecToAddTo, proshade_signed *elementToAdd)
| Adds the element to the vector. More...
void | ProSHADE_internal_misc::addToUnsignVectorVector (std::vector< std::vector< proshade_unsign > > *vecToAddTo, std::vector< proshade_unsign > elementToAdd)
| Adds the element to the vector of vectors. More...
void | ProSHADE_internal_misc::addToDoubleVectorVector (std::vector< std::vector< proshade_double > > *vecToAddTo, std::vector< proshade_double > elementToAdd)
| Adds the element to the vector of vectors. More...
bool | ProSHADE_internal_misc::sortSymHlp (const proshade_double *a, const proshade_double *b)
| This function compares two arrays of two based on the fifth number, sorting lowest first. More...
bool | ProSHADE_internal_misc::sortSymHlpInv (const proshade_double *a, const proshade_double *b)
| This function compares two arrays of two based on the fifth number, sorting highest first. More...
bool | ProSHADE_internal_misc::sortDSymHlpInv (const proshade_double *a, const proshade_double *b)
| This function compares two arrays of the ProSHADE dihedral symmetry list based on combination of axes folds and heightst. More...
bool | ProSHADE_internal_misc::sortSymInvFoldHlp (const proshade_double *a, const proshade_double *b)
| This function compares two arrays of two based on the first number, sorting highest first. More...
void | ProSHADE_internal_misc::deepCopyAxisToDblPtrVector (std::vector< proshade_double * > *dblPtrVec, proshade_double *axis)
| Does a deep copy of a double array to a vector of double arrays. More...
void | ProSHADE_internal_misc::deepCopyBoundsSigPtrVector (std::vector< proshade_signed * > *sigPtrVec, proshade_signed *xFrom, proshade_signed *xTo, proshade_signed *yFrom, proshade_signed *yTo, proshade_signed *zFrom, proshade_signed *zTo)
| Does a deep copy of a signed int array to a vector of signed int arrays. More...
template<class chVar >
void | ProSHADE_internal_misc::checkMemoryAllocation (chVar checkVar, std::string fileP, unsigned int lineP, std::string funcP, std::string infoP="This error may occurs when ProSHADE requests memory to be\n : allocated to it and this operation fails. This could\n : happen when not enough memory is available, either due to\n : other processes using a lot of memory, or when the machine\n : does not have sufficient memory available. Re-run to see\n : if this problem persists.")
| Checks if memory was allocated properly. More...

## Detailed Description

This header file declares all miscellaneous functions.

The functions declared in here are used by ProSHADE to deal with minor tasks unrelated to anything in the main library of functions, such as memory allocation checking and C++ version independent vector extension.

Copyright by Michal Tykac and individual contributors. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met: 1) Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer. 2) Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution. 3) Neither the name of Michal Tykac nor the names of this code's contributors may be used to endorse or promote products derived from this software without specific prior written permission.

This software is provided by the copyright holder and contributors "as is" and any express or implied warranties, including, but not limitted to, the implied warranties of merchantibility and fitness for a particular purpose are disclaimed. In no event shall the copyright owner or the contributors be liable for any direct, indirect, incidental, special, exemplary, or consequential damages (including, but not limitted to, procurement of substitute goods or services, loss of use, data or profits, or business interuption) however caused and on any theory of liability, whether in contract, strict liability or tort (including negligence or otherwise) arising in any way out of the use of this software, even if advised of the possibility of such damage.

Author
  Michal Tykac
  Garib N. Murshudov

Version
  0.7.5.1

Date
  JAN 2021

Definition in file ProSHADE_misc.hpp.